/* GrandPerspective, Version 2.5.2 
 *   A utility for Mac OS X that graphically shows disk usage. 
 * Copyright (C) 2005-2020, Erwin Bonsma 
 * 
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the Free 
 * Software Foundation; either version 2 of the License, or (at your option) 
 * any later version. 
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
 * more details. 
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. 
 */

#import "FilterTaskInput.h"

#import "TreeContext.h"
#import "PreferencesPanelControl.h"


@implementation FilterTaskInput

// Overrides designated initialiser
- (instancetype) init {
  NSAssert(NO, @"Use initWithOldContext:filterSet: instead");
  return [self initWithTreeContext: nil filterSet: nil];
}

- (instancetype) initWithTreeContext:(TreeContext *)treeContextVal
                           filterSet:(FilterSet *)filterSetVal {
  NSUserDefaults  *userDefaults = [NSUserDefaults standardUserDefaults];
  
  BOOL  showPackageContentsByDefault =
    [userDefaults boolForKey: ShowPackageContentsByDefaultKey] ? NSOnState : NSOffState;

  return [self initWithTreeContext: treeContextVal
                         filterSet: filterSetVal
                   packagesAsFiles: !showPackageContentsByDefault];
}

- (instancetype) initWithTreeContext:(TreeContext *)treeContext
                           filterSet:(FilterSet *)filterSet
                     packagesAsFiles:(BOOL) packagesAsFiles {
  if (self = [super init]) {
    _treeContext = [treeContext retain];
    _filterSet = [filterSet retain];
    
    packagesAsFiles = packagesAsFiles;
  }
  return self;
}

- (void) dealloc {
  [_treeContext release];
  [_filterSet release];
  
  [super dealloc];
}

@end
